/* externally usable routines to interface to the multiple-kanji popup window
 * (primarily used by the search window)
 */

extern void MakeMulti();
extern void ClearAllMulti();
extern void AddMultiTranslation(TRANSLATION);
extern int getMultiMax();
extern int getMultiCount();

extern void ShowMulti();
extern void setmultilabels();
